BlockLocator

Struct BlockLocator 

pub struct BlockLocator {
    pub block_hash: BlockHash,
    pub height: u32,
    pub previous_blocks: [Option<BlockHash>; 12],
}
Identifies a position in the chain by its block hash and height, along with recent ancestor hashes used to locate the fork point of a reorg.

Fields

block_hash: BlockHash

The block’s hash.

height: u32

The block’s height.

previous_blocks: [Option<BlockHash>; 12]

Ancestor block hashes immediately before Self::block_hash, in reverse chronological order.

These ensure we can find the fork point of a reorg if our block source no longer has the previous tip after a restart.

Implementations

Source

impl BlockLocator

pub fn from_network(network: Network) -> Self

Constructs a BlockLocator that represents the genesis block at height 0 of the given network.

pub fn new(block_hash: BlockHash, height: u32) -> Self

Returns a BlockLocator as identified by the given block hash and height.

This is not exported to bindings users directly as the bindings auto-generate an equivalent new.

pub fn advance(&mut self, new_hash: BlockHash)

Advances to a new block at height Self::height + 1.

pub fn update_for_new_tip( &mut self, new_tip_hash: BlockHash, new_tip_height: u32, )

Updates this locator for a new chain tip, either delegating to Self::advance if the new block is simply one higher than the current tip and wiping Self::previous_blocks if a few blocks have been skipped.

pub fn get_hash_at_height(&self, height: u32) -> Option<BlockHash>

Returns the block hash at the given height, if available in our history.

pub fn find_common_ancestor( &self, other: &BlockLocator, ) -> Option<(BlockHash, u32)>

Finds the most recent common ancestor between two BlockLocators by searching their ancestor hash histories.

Returns the common block hash and height, or None if no common block is found in the available histories.