Struct lightning::chain::WatchedOutput
source · [−]pub struct WatchedOutput {
pub block_hash: Option<BlockHash>,
pub outpoint: OutPoint,
pub script_pubkey: Script,
}Expand description
A transaction output watched by a ChannelMonitor for spends on-chain.
Used to convey to a Filter such an output with a given spending condition. Any transaction
spending the output must be given to ChannelMonitor::block_connected either directly or via
Confirm::transactions_confirmed.
If block_hash is Some, this indicates the output was created in the corresponding block and
may have been spent there. See Filter::register_output for details.
Fields
block_hash: Option<BlockHash>First block where the transaction output may have been spent.
outpoint: OutPointOutpoint identifying the transaction output.
script_pubkey: ScriptSpending condition of the transaction output.