pub struct OutPoint {
pub txid: Txid,
pub index: u16,
}Expand description
A reference to a transaction output.
Differs from bitcoin::transaction::OutPoint as the index is a u16 instead of u32 due to LN’s restrictions on index values. Should reduce (possibly) unsafe conversions this way.
Fields
txid: TxidThe referenced transaction’s txid.
index: u16The index of the referenced output in its transaction’s vout.
Implementations
Sourceimpl OutPoint
impl OutPoint
Sourcepub fn into_bitcoin_outpoint(self) -> BitcoinOutPoint
pub fn into_bitcoin_outpoint(self) -> BitcoinOutPoint
Converts this OutPoint into the OutPoint field as used by rust-bitcoin
This is not exported to bindings users as the same type is used universally in the C bindings for all outpoints