DecodeError

Enum DecodeError 

pub enum DecodeError {
    UnknownVersion,
    UnknownRequiredFeature,
    InvalidValue,
    ShortRead,
    BadLengthDescriptor,
    Io(ErrorKind),
    UnsupportedCompression,
    DangerousValue,
}
An error in decoding a message or struct.

Variants



UnknownVersion

A version byte specified something we don’t know how to handle.

Includes unknown realm byte in an onion hop data packet.



UnknownRequiredFeature

Unknown feature mandating we fail to parse message (e.g., TLV with an even, unknown type)



InvalidValue

Value was invalid.

For example, a byte which was supposed to be a bool was something other than a 0 or 1, a public key/private key/signature was invalid, text wasn’t UTF-8, TLV was syntactically incorrect, etc.



ShortRead

The buffer to be read was too short.



BadLengthDescriptor

A length descriptor in the packet didn’t describe the later data correctly.



Io(ErrorKind)

Error from crate::io.



UnsupportedCompression

The message included zlib-compressed values, which we don’t support.



DangerousValue

Value is validly encoded but is dangerous to use.

This is used for things like ChannelManager deserialization where we want to ensure that we don’t use a ChannelManager which is in out of sync with the ChannelMonitor. This indicates that there is a critical implementation flaw in the storage implementation and it’s unsafe to continue.