ChannelParameters

Struct ChannelParameters 

pub struct ChannelParameters {
    pub dust_limit_satoshis: u64,
    pub max_htlc_value_in_flight_msat: u64,
    pub htlc_minimum_msat: u64,
    pub commitment_feerate_sat_per_1000_weight: u32,
    pub to_self_delay: u16,
    pub max_accepted_htlcs: u16,
}
A subset of CommonOpenChannelFields, containing various parameters which are set by the channel initiator and which are not part of the channel funding transaction.

Fields

dust_limit_satoshis: u64

The threshold below which outputs on transactions broadcast by the channel initiator will be omitted.

max_htlc_value_in_flight_msat: u64

The maximum inbound HTLC value in flight towards channel initiator, in milli-satoshi

htlc_minimum_msat: u64

The minimum HTLC size for HTLCs towards the channel initiator, in milli-satoshi

commitment_feerate_sat_per_1000_weight: u32

The feerate for the commitment transaction set by the channel initiator until updated by UpdateFee

to_self_delay: u16

The number of blocks which the non-channel-initator will have to wait to claim on-chain funds if they broadcast a commitment transaction.

max_accepted_htlcs: u16

The maximum number of pending HTLCs towards the channel initiator.