pub struct UnsignedNodeAnnouncement {
pub features: NodeFeatures,
pub timestamp: u32,
pub node_id: NodeId,
pub rgb: [u8; 3],
pub alias: NodeAlias,
pub addresses: Vec<SocketAddress>,
pub excess_address_data: Vec<u8>,
pub excess_data: Vec<u8>,
}Expand description
The unsigned part of a node_announcement message.
Fields
features: NodeFeaturesThe advertised features
timestamp: u32A strictly monotonic announcement counter, with gaps allowed
node_id: NodeIdThe node_id this announcement originated from (don’t rebroadcast the node_announcement back
to this node).
rgb: [u8; 3]An RGB color for UI purposes
alias: NodeAliasAn alias, for UI purposes.
This should be sanitized before use. There is no guarantee of uniqueness.
addresses: Vec<SocketAddress>List of addresses on which this node is reachable
excess_address_data: Vec<u8>Excess address data which was signed as a part of the message which we do not (yet) understand how to decode.
This is stored to ensure forward-compatibility as new address types are added to the lightning gossip protocol.
excess_data: Vec<u8>Excess data which was signed as a part of the message which we do not (yet) understand how to decode.
This is stored to ensure forward-compatibility as new fields are added to the lightning gossip protocol.