Struct lightning::ln::PaymentHash
source · pub struct PaymentHash(pub [u8; 32]);Expand description
payment_hash type, use to cross-lock hop
This is not exported to bindings users as we just use [u8; 32] directly
Tuple Fields
0: [u8; 32]Trait Implementations
sourceimpl Clone for PaymentHash
impl Clone for PaymentHash
sourcefn clone(&self) -> PaymentHash
fn clone(&self) -> PaymentHash
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PaymentHash
impl Debug for PaymentHash
sourceimpl Display for PaymentHash
impl Display for PaymentHash
sourceimpl Hash for PaymentHash
impl Hash for PaymentHash
sourceimpl Ord for PaymentHash
impl Ord for PaymentHash
sourcefn cmp(&self, other: &PaymentHash) -> Ordering
fn cmp(&self, other: &PaymentHash) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for PaymentHash
impl PartialEq for PaymentHash
sourcefn eq(&self, other: &PaymentHash) -> bool
fn eq(&self, other: &PaymentHash) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for PaymentHash
impl PartialOrd for PaymentHash
sourcefn partial_cmp(&self, other: &PaymentHash) -> Option<Ordering>
fn partial_cmp(&self, other: &PaymentHash) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Readable for PaymentHash
impl Readable for PaymentHash
sourceimpl Writeable for PaymentHash
impl Writeable for PaymentHash
impl Copy for PaymentHash
impl Eq for PaymentHash
impl StructuralEq for PaymentHash
impl StructuralPartialEq for PaymentHash