Quantity

Enum Quantity 

pub enum Quantity {
    Bounded(NonZeroU64),
    Unbounded,
    One,
}
Quantity of items supported by an Offer.

Variants



Bounded(NonZeroU64)

Up to a specific number of items (inclusive). Use when more than one item can be requested but is limited (e.g., because of per customer or inventory limits).

May be used with NonZeroU64::new(1) but prefer to use Quantity::One if only one item is supported.



Unbounded

One or more items. Use when more than one item can be requested without any limit.



One

Only one item. Use when only a single item can be requested.