pub trait Writer {
// Required method
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>;
}Expand description
A simplified version of std::io::Write that exists largely for backwards compatibility.
An impl is provided for any type that also impls std::io::Write.
This is not exported to bindings users as we only export serialization to/from byte arrays instead
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".